Index: /anuga_core/source/anuga/abstract_2d_finite_volumes/test_util.py
===================================================================
--- /anuga_core/source/anuga/abstract_2d_finite_volumes/test_util.py	(revision 7339)
+++ /anuga_core/source/anuga/abstract_2d_finite_volumes/test_util.py	(revision 7340)
@@ -17,5 +17,5 @@
 from anuga.pmesh.mesh import Mesh
 from anuga.shallow_water import Domain, Transmissive_boundary
-from anuga.shallow_water.data_manager import get_dataobject
+from anuga.shallow_water.data_manager import SWW_file
 from csv import reader,writer
 import time
@@ -169,5 +169,5 @@
         #Now read data from sww and check
         from Scientific.IO.NetCDF import NetCDFFile
-        filename = domain1.get_name() + '.' + domain1.format
+        filename = domain1.get_name() + '.sww'
         fid = NetCDFFile(filename)
 
@@ -381,5 +381,5 @@
         #Now read data from sww and check
         from Scientific.IO.NetCDF import NetCDFFile
-        filename = domain1.get_name() + '.' + domain1.format
+        filename = domain1.get_name() + '.sww'
         fid = NetCDFFile(filename)
 
@@ -630,5 +630,4 @@
         domain.set_name(filename)
         domain.store = True
-        domain.format = 'sww'   #Native netcdf visualisation format
 
         #print points
@@ -656,5 +655,5 @@
             #Store and advance time
             domain.time = t
-            domain.store_timestep(domain.conserved_quantities)
+            domain.store_timestep()
             t += dt
 
@@ -796,5 +795,4 @@
         domain.set_name(filename)
         domain.store = True
-        domain.format = 'sww'   #Native netcdf visualisation format
 
         #print points
@@ -1614,10 +1612,9 @@
 
         domain.set_name('datatest' + str(time.time()))
-        domain.format = 'sww'
         domain.smooth = True
         domain.reduction = mean
 
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum','elevation'])
@@ -1687,5 +1684,4 @@
         from anuga.pmesh.mesh import Mesh
         from anuga.shallow_water import Domain, Transmissive_boundary
-        from anuga.shallow_water.data_manager import get_dataobject
         from csv import reader,writer
         import time
@@ -1737,9 +1733,8 @@
 
         domain.set_name('datatest' + str(time.time()))
-        domain.format = 'sww'
         domain.smooth = True
         domain.reduction = mean
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum'])
@@ -1857,9 +1852,8 @@
 
         domain.set_name('datatest' + str(time.time()))
-        domain.format = 'sww'
         domain.smooth = True
         domain.reduction = mean
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum','elevation'])
Index: /anuga_core/source/anuga/damage_modelling/test_inundation_damage.py
===================================================================
--- /anuga_core/source/anuga/damage_modelling/test_inundation_damage.py	(revision 7339)
+++ /anuga_core/source/anuga/damage_modelling/test_inundation_damage.py	(revision 7340)
@@ -15,5 +15,5 @@
 from anuga.shallow_water import Domain, Transmissive_boundary
 from anuga.utilities.numerical_tools import mean
-from anuga.shallow_water.data_manager import get_dataobject
+from anuga.shallow_water.data_manager import SWW_file
 
 import numpy as num
@@ -112,5 +112,5 @@
         self.domain.reduction = mean
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum'])
@@ -182,5 +182,5 @@
         domain.reduction = mean
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum'])
@@ -282,5 +282,5 @@
         domain.reduction = mean
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum'])
@@ -354,5 +354,5 @@
         domain.reduction = mean
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum'])
Index: /anuga_core/source/anuga/fit_interpolate/test_interpolate.py
===================================================================
--- /anuga_core/source/anuga/fit_interpolate/test_interpolate.py	(revision 7339)
+++ /anuga_core/source/anuga/fit_interpolate/test_interpolate.py	(revision 7340)
@@ -24,5 +24,5 @@
 from anuga.shallow_water import Domain, Transmissive_boundary
 from anuga.utilities.numerical_tools import mean, NAN
-from anuga.shallow_water.data_manager import get_dataobject
+from anuga.shallow_water.data_manager import SWW_file
 from anuga.geospatial_data.geospatial_data import Geospatial_data
 from anuga.pmesh.mesh import Mesh
@@ -1710,9 +1710,8 @@
 
         domain.set_name('datatest' + str(time.time()))
-        domain.format = 'sww'
         domain.smooth = True
         domain.reduction = mean
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep(['stage', 'xmomentum', 'ymomentum'])
Index: /anuga_core/source/anuga/shallow_water/data_manager_joaquims_patch.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/data_manager_joaquims_patch.py	(revision 7339)
+++ /anuga_core/source/anuga/shallow_water/data_manager_joaquims_patch.py	(revision 7340)
@@ -292,5 +292,5 @@
 
 #Class for storing output to e.g. visualisation
-class Data_format_sww(Data_format):
+class SWW_file(Data_format):
     """Interface to native NetCDF format (.sww) for storing model output
 
@@ -487,5 +487,5 @@
             # Build a new data_structure.
             next_data_structure=\
-                Data_format_sww(self.domain, mode=self.mode,\
+                SWW_file(self.domain, mode=self.mode,\
                                 max_size = self.max_size,\
                                 recursion = self.recursion+1)
@@ -1226,14 +1226,4 @@
     infile.close()
     outfile.close()
-
-
-#Get data objects
-def get_dataobject(domain, mode='w'):
-    """Return instance of class of given format using filename
-    """
-
-    cls = eval('Data_format_%s' %domain.format)
-    return cls(domain, mode)
-
 
 
@@ -3579,5 +3569,5 @@
         print "Output written to " + domain.get_datadir() + sep + \
               domain.get_name() + "." + domain.format
-    sww = get_dataobject(domain)
+    sww = SWW_file(domain)
     sww.store_connectivity()
     sww.store_timestep('stage')
Index: /anuga_core/source/anuga/shallow_water/shallow_water_domain.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/shallow_water_domain.py	(revision 7339)
+++ /anuga_core/source/anuga/shallow_water/shallow_water_domain.py	(revision 7340)
@@ -209,5 +209,5 @@
         # Stored output
         self.store = True
-        self.format = 'sww'
+        #self.format = 'sww'
         self.set_store_vertices_uniquely(False)
         self.minimum_storable_height = minimum_storable_height
@@ -638,10 +638,4 @@
         if self.store is True and self.time == 0.0:
             self.initialise_storage()
-        else:
-            pass
-            # print 'Results will not be stored.'
-            # print 'To store results set domain.store = True'
-            # FIXME: Diagnostic output should be controlled by
-            # a 'verbose' flag living in domain (or in a parent class)
 
         # Call basic machinery from parent class
@@ -651,8 +645,5 @@
             # Store model data, e.g. for subsequent visualisation
             if self.store is True:
-                self.store_timestep(self.quantities_to_be_stored)
-
-            # FIXME: Could maybe be taken from specified list
-            # of 'store every step' quantities
+                self.store_timestep()
 
             # Pass control on to outer loop for more specific actions
@@ -666,8 +657,8 @@
         """
 
-        from anuga.shallow_water.data_manager import get_dataobject
+        from anuga.shallow_water.data_manager import SWW_file
 
         # Initialise writer
-        self.writer = get_dataobject(self, mode=netcdf_mode_w)
+        self.writer = SWW_file(self)
 
         # Store vertices and connectivity
@@ -677,12 +668,12 @@
     # @brief 
     # @param name 
-    def store_timestep(self, name):
-        """Store named quantity and time.
+    def store_timestep(self):
+        """Store time dependent quantities and time.
 
         Precondition:
-           self.write has been initialised
-        """
-
-        self.writer.store_timestep(name)
+           self.writer has been initialised
+        """
+
+        self.writer.store_timestep()
 
     ##
Index: /anuga_core/source/anuga/shallow_water/test_data_manager.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/test_data_manager.py	(revision 7339)
+++ /anuga_core/source/anuga/shallow_water/test_data_manager.py	(revision 7340)
@@ -179,5 +179,5 @@
         self.domain.smooth = False
         
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
 
@@ -211,5 +211,5 @@
         self.domain.smooth = False
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
 
@@ -240,5 +240,5 @@
         self.domain.set_store_vertices_uniquely(True)
         
-        sww = get_dataobject(self.domain)        
+        sww = SWW_file(self.domain)        
 
         dqs = self.domain.get_quantity('stage')
@@ -327,5 +327,5 @@
         
         
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
 
         for t in domain.evolve(yieldstep = 1, finaltime = 1):
@@ -379,5 +379,5 @@
         self.domain.smooth = True
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
 
@@ -419,5 +419,5 @@
         self.domain.reduction = mean
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -466,5 +466,5 @@
         self.domain.reduction = mean
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -522,5 +522,5 @@
         self.domain.reduction = min
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -624,5 +624,5 @@
         self.domain.minimum_storable_height = 100
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -678,5 +678,5 @@
         self.domain.reduction = mean
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -1257,5 +1257,5 @@
         self.domain.geo_reference = Geo_reference(56, 308500, 6189000)
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -1458,5 +1458,5 @@
         self.domain.geo_reference = Geo_reference(56,308500,6189000)
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -1539,9 +1539,9 @@
         self.domain.geo_reference = Geo_reference(56,308500,6189000)
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
-        sww.store_timestep() #'stage')
+        sww.store_timestep()
         self.domain.evolve_to_end(finaltime = 0.01)
-        sww.store_timestep() #'stage')
+        sww.store_timestep()
 
         cellsize = 0.25
@@ -1677,5 +1677,5 @@
         self.domain.geo_reference = Geo_reference(56,308500,6189000)
         
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep() #'stage')
@@ -1816,5 +1816,5 @@
         self.domain.geo_reference = Geo_reference(56,308500,6189000)
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -1823,5 +1823,5 @@
         self.domain.set_name(base_name+'_P1_8')
         swwfile2 = self.domain.get_name() + '.sww'
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -1981,5 +1981,5 @@
 
         #
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -2172,5 +2172,5 @@
 
         #
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -2321,5 +2321,5 @@
 
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -2433,5 +2433,5 @@
 
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -2586,5 +2586,5 @@
         domain.geo_reference = Geo_reference(56,308500,6189000)
 
-        sww = get_dataobject(domain)
+        sww = SWW_file(domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -2692,5 +2692,5 @@
         self.domain.geo_reference = Geo_reference(56,308500,6189000)
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -2790,5 +2790,5 @@
         self.domain.geo_reference = Geo_reference(56,308500,6189000)
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
@@ -3548,5 +3548,5 @@
 
 
-        sww = get_dataobject(self.domain)
+        sww = SWW_file(self.domain)
         sww.store_connectivity()
         sww.store_timestep()
Index: /anuga_core/source/anuga/shallow_water/test_shallow_water_domain.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/test_shallow_water_domain.py	(revision 7339)
+++ /anuga_core/source/anuga/shallow_water/test_shallow_water_domain.py	(revision 7340)
@@ -1465,5 +1465,5 @@
         # Cleanup
         try:
-            os.remove(domain.get_name() + '.' + domain.format)
+            os.remove(domain.get_name() + '.sww')
         except:
             pass
@@ -5148,5 +5148,5 @@
         # Boundary conditions
         Br = Reflective_boundary(domain2)
-        Bf = Field_boundary(domain1.get_name() + '.' + domain1.format, domain2)
+        Bf = Field_boundary(domain1.get_name() + '.sww', domain2)
         domain2.set_boundary({'right':Br, 'bottom':Br, 'diagonal':Bf})
         domain2.check_integrity()
@@ -5168,6 +5168,6 @@
 
         # Cleanup
-        os.remove(domain1.get_name() + '.' + domain1.format)
-        os.remove(domain2.get_name() + '.' + domain2.format)
+        os.remove(domain1.get_name() + '.sww')
+        os.remove(domain2.get_name() + '.sww')
 
     def test_spatio_temporal_boundary_2(self):
@@ -5251,5 +5251,5 @@
         # Read results for specific timesteps t=1 and t=2
         from Scientific.IO.NetCDF import NetCDFFile
-        fid = NetCDFFile(domain1.get_name() + '.' + domain1.format)
+        fid = NetCDFFile(domain1.get_name() + '.sww')
 
         x = fid.variables['x'][:]
@@ -5273,5 +5273,5 @@
         # Boundary conditions
         Br = Reflective_boundary(domain2)
-        Bf = Field_boundary(domain1.get_name() + '.' + domain1.format,
+        Bf = Field_boundary(domain1.get_name() + '.sww',
                             domain2, verbose=False)
         domain2.set_boundary({'right':Br, 'bottom':Br, 'diagonal':Bf})
@@ -5338,5 +5338,5 @@
 
         # Cleanup
-        os.remove(domain1.get_name() + '.' + domain1.format)
+        os.remove(domain1.get_name() + '.sww')
 
     def test_spatio_temporal_boundary_3(self):
@@ -5425,5 +5425,5 @@
         # Read results for specific timesteps t=1 and t=2
         from Scientific.IO.NetCDF import NetCDFFile
-        fid = NetCDFFile(domain1.get_name() + '.' + domain1.format)
+        fid = NetCDFFile(domain1.get_name() + '.sww')
 
         x = fid.variables['x'][:]
@@ -5447,5 +5447,5 @@
         # Boundary conditions
         Br = Reflective_boundary(domain2)
-        Bf = Field_boundary(domain1.get_name() + '.' + domain1.format,
+        Bf = Field_boundary(domain1.get_name() + '.sww',
                             domain2, mean_stage=mean_stage, verbose=False)
 
@@ -5516,5 +5516,5 @@
 
         # Cleanup
-        os.remove(domain1.get_name() + '.' + domain1.format)
+        os.remove(domain1.get_name() + '.sww')
 
     def test_spatio_temporal_boundary_outside(self):
@@ -5598,5 +5598,5 @@
         # Read results for specific timesteps t=1 and t=2
         from Scientific.IO.NetCDF import NetCDFFile
-        fid = NetCDFFile(domain1.get_name() + '.' + domain1.format)
+        fid = NetCDFFile(domain1.get_name() + '.sww')
 
         x = fid.variables['x'][:]
@@ -5616,5 +5616,5 @@
         # Boundary conditions
         Br = Reflective_boundary(domain2)
-        Bf = Field_boundary(domain1.get_name() + '.' + domain1.format,
+        Bf = Field_boundary(domain1.get_name() + '.sww',
                             domain2, mean_stage=1, verbose=False)
 
@@ -5632,5 +5632,5 @@
 
         #Cleanup
-        os.remove(domain1.get_name() + '.' + domain1.format)
+        os.remove(domain1.get_name() + '.sww')
 
     def test_extrema(self):
@@ -5730,5 +5730,5 @@
 
         # Cleanup
-        os.remove(domain.get_name() + '.' + domain.format)
+        os.remove(domain.get_name() + '.sww')
 
     def test_tight_slope_limiters(self):
@@ -5739,5 +5739,5 @@
         import time, os
         from Scientific.IO.NetCDF import NetCDFFile
-        from data_manager import get_dataobject, extent_sww
+        from data_manager import extent_sww
         from mesh_factory import rectangular
 
@@ -5787,5 +5787,4 @@
 
         domain.set_name('tight_limiters')
-        domain.format = 'sww'
         domain.smooth = True
         domain.reduction = mean
Index: /anuga_core/source/anuga/shallow_water/tsh2sww.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/tsh2sww.py	(revision 7339)
+++ /anuga_core/source/anuga/shallow_water/tsh2sww.py	(revision 7340)
@@ -13,5 +13,5 @@
 from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance
 import time, os 
-from anuga.pyvolution.data_manager import get_dataobject   
+from anuga.pyvolution.data_manager import SWW_file
 from anuga.utilities.numerical_tools import mean
 import anuga.utilities.log as log
@@ -49,5 +49,5 @@
                      % (domain.get_datadir(), sep, domain.get_name(),
                         domain.format)
-    sww = get_dataobject(domain)
+    sww = SWW_file(domain)
     sww.store_connectivity()
     sww.store_timestep('stage')

Index: /anuga_core/source/anuga/shallow_water/data_manager.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/data_manager.py	(revision 7339)
+++ /anuga_core/source/anuga/shallow_water/data_manager.py	(revision 7340)
@@ -329,5 +329,5 @@
 ##
 # @brief Class for storing output to e.g. visualisation
-class Data_format_sww(Data_format):
+class SWW_file(Data_format):
     """Interface to native NetCDF format (.sww) for storing model output
 
@@ -434,10 +434,4 @@
         fid = NetCDFFile(self.filename, netcdf_mode_a)
 
-#        # Get the variables
-#        x = fid.variables['x']
-#        y = fid.variables['y']
-#        z = fid.variables['elevation']
-#        volumes = fid.variables['volumes']
-
         # Get X, Y and bed elevation Z
         Q = domain.quantities['elevation']
@@ -456,9 +450,8 @@
 
     ##
-    # @brief Store time and named quantities to the underlying data file.
-    # @param names The names of the quantities to store.
-    # @note If 'names' not supplied, store a standard set of quantities.
+    # @brief Store time and time dependent quantities 
+    # to the underlying data file.
     def store_timestep(self, names=None):
-        """Store time and named quantities to file
+        """Store time and time dependent quantities
         """
 
@@ -468,7 +461,6 @@
         from os import stat
 
-        if names is None:
-            # Standard shallow water wave equation quantitites in ANUGA
-            names = ['stage', 'xmomentum', 'ymomentum']
+        # Get names of quantities to be stored every time step
+        names = self.writer.dynamic_quantities    
 
         # Get NetCDF
@@ -521,5 +513,5 @@
 
             # Build a new data_structure.
-            next_data_structure = Data_format_sww(self.domain, mode=self.mode,
+            next_data_structure = SWW_file(self.domain, mode=self.mode,
                                                   max_size=self.max_size,
                                                   recursion=self.recursion+1)
@@ -618,6 +610,8 @@
 ##
 # @brief Class for handling checkpoints data
-class Data_format_cpt(Data_format):
-    """Interface to native NetCDF format (.cpt)
+# @note This is not operational at the moment
+class CPT_file(Data_format):
+    """Interface to native NetCDF format (.cpt) to be 
+    used for checkpointing (one day)
     """
 
@@ -705,5 +699,5 @@
 
     ##
-    # @brief Store tiem and named quantities to underlying data file.
+    # @brief Store time and named quantities to underlying data file.
     # @param name 
     def store_timestep(self, name):
@@ -1464,18 +1458,4 @@
     infile.close()
     outfile.close()
-
-
-##
-# @brief Return instance of class of given format using filename.
-# @param domain Data domain (eg, 'sww', etc).
-# @param mode The mode to open domain in.
-# @return A class instance of required domain and mode.
-#Get data objects
-def get_dataobject(domain, mode=netcdf_mode_w):
-    """Return instance of class of given format using filename
-    """
-
-    cls = eval('Data_format_%s' % domain.format)
-    return cls(domain, mode)
 
 
@@ -3987,5 +3967,5 @@
                         domain.format))
 
-    sww = get_dataobject(domain)
+    sww = SWW_file(domain)
     sww.store_connectivity()
     sww.store_timestep()
@@ -5323,5 +5303,5 @@
     volumes = mesh_dic['generatedtrianglelist']
 
-    # write sww intro and grid stuff.
+    # Write sww intro and grid stuff.
     if basename_out is None:
         swwname = basename_in + '.sww'
@@ -5983,8 +5963,7 @@
             outfile.variables[q+Write_sww.RANGE][1] = -max_float # Max
 
-        # FIXME: Backwartds compat get rid of z once old view has retired        
-                               
+        # FIXME: Backwards compat - get rid of z once old view has retired
         outfile.createVariable('z', sww_precision,
-                               ('number_of_points',))                               
+                               ('number_of_points',))
                                
         for q in self.dynamic_quantities:
@@ -6000,5 +5979,5 @@
 
         if isinstance(times, (list, num.ndarray)):
-            outfile.variables['time'][:] = times    #Store time relative
+            outfile.variables['time'][:] = times    # Store time relative
 
         if verbose:
@@ -6097,5 +6076,4 @@
             log.critical('------------------------------------------------')
 
-        #z = resize(bath_grid, outfile.variables['z'][:].shape)
         outfile.variables['x'][:] = points[:,0] #- geo_ref.get_xllcorner()
         outfile.variables['y'][:] = points[:,1] #- geo_ref.get_yllcorner()
@@ -6118,12 +6096,16 @@
     # @param verbose True if this function is to be verbose.
     # @param **quant
-    def store_quantities(self, outfile, sww_precision=num.float32,
-                         slice_index=None, time=None,
-                         verbose=False, **quant):
+    def store_quantities(self, 
+                         outfile, 
+                         sww_precision=num.float32,
+                         slice_index=None,
+                         time=None,
+                         verbose=False, 
+                         **quant):
         """
-        Write the quantity info.
+        Write the quantity info at each timestep.
 
         **quant is extra keyword arguments passed in. These must be
-          the sww quantities, currently; stage, xmomentum, ymomentum.
+          the numpy arrays to be stored in the sww file at each timestep.
 
         if the time array is already been built, use the slice_index
@@ -6140,6 +6122,6 @@
 
         Precondition:
-            triangulation and
-            header have been called.
+            store_triangulation and
+            store_header have been called.
         """
 
@@ -6149,14 +6131,19 @@
             file_time[slice_index] = time
         else:
-            slice_index = int(slice_index) # In case it was numpy.int    
-
-        # Write the conserved quantities from Domain.
-        # Typically stage,  xmomentum, ymomentum
-        # other quantities will be ignored, silently.
-        # Also write the ranges: stage_range,
-        # xmomentum_range and ymomentum_range
+            slice_index = int(slice_index) # Has to be cast in case it was numpy.int    
+
+        # Write the named dynamic quantities
+        # The dictionary quant must contain numpy arrays for each name.
+        # These will typically be the conserved quantities from Domain 
+        # (Typically stage,  xmomentum, ymomentum).
+        #
+        # Arrays not listed in dynamic_quantitiues will be ignored, silently.
+        #
+        # This method will also write the ranges for each quantity, 
+        # e.g. stage_range, xmomentum_range and ymomentum_range
         for q in self.dynamic_quantities:
             if not quant.has_key(q):
-                msg = 'SWW file can not write quantity %s' % q
+                msg = 'Values for quantity %s was not specified in ' % q
+                msg += 'store_quantities so they cannot be stored.'
                 raise NewQuantity, msg
             else: